@@ -2,9 +2,11 @@
  * @Author: tzw
  * @Date: 2021-10-31 23:40:16
  * @LastEditors: tzw
- * @LastEditTime: 2021-10-31 23:59:43
+ * @LastEditTime: 2021-11-29 22:22:27
  */
 
 pub mod domain_event;
 pub mod eventuate_message;
+pub mod event;
+pub mod aggregate;
 
